#!/bin/bash

clear

uname=$(logname || loginctl user-status|awk 'NR==1{print $1}' || who | awk '{ print $1 }' | head -n 1)
case $uname in
    "root")
        homedir="/${uname}"
        ;;

    *)
        homedir="/home/${uname}"
        ;;
esac

install_log="${homedir}/nmagent_install.log"

echo "Запуск процесса установки продукта..." &> $install_log

script_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &>/dev/null && pwd -P)
repo_path="${script_dir}/nmagentrepo"

sudo mkdir -p $repo_path
if [[ $? -ne 0 ]]
then
    echo "Не удалось создать каталог ($repo_path) для монтирования образа с репозиторием. Выходим по ошибке" &>> $install_log
    exit 1
fi

sudo mount nmagent-repo.iso -o loop $repo_path
if [[ $? -ne 0 ]]
then
    echo "Не удалось смонтировать образ с репозиторием. Выходим по ошибке" &>> $install_log
    exit 1
fi

os_version=$(lsb_release -r | awk '{ print $2 }')
echo "Версия ОС ($os_version)" &>> $install_log

cd $repo_path
sudo $repo_path/add_repo_localy.sh
case $? in
    "0")
        echo "Успешно добавили репозиторий в систему" &>> $install_log
        ;;
    "50")
        echo "Не удалось добавить в систему публичный ключ репозитория. Выходим по ошибке" &>> $install_log
        cd ..
        sudo umount $repo_path
        sudo rmdir $repo_path
        exit 1
        ;;
    "51")
        echo "Не удалось добавить информацию о репозитории в систему. Выходим по ошибке" &>> $install_log
        cd ..
        sudo umount $repo_path
        sudo rmdir $repo_path
        exit 1
        ;;
    "52")
        echo "Обнаружены ошибки при обновлении репозиториев в системе. Продолжаем установку..." &>> $install_log
        ;;
    *)
        echo "Не удалось запустить скрипт add_repo_localy.sh. Выходим по ошибке" &>> $install_log
        cd ..
        sudo umount $repo_path
        sudo rmdir $repo_path
        exit 1
        ;;
esac

cd ..

deb_package_name=`basename $(find $repo_path/pool -type f -name 10-strike-nmagent*.deb)`
echo "Запуск установки пакета $deb_package_name" &>> $install_log
sudo apt install 10-strike-nmagent
if [[ $? -ne 0 ]]
then
    echo "Не удалось установить пакет 10-strike-nmagent или операция прервана пользователем" &>> $install_log
    sudo umount $repo_path
    sudo rmdir $repo_path
    sudo rm -f /etc/apt/sources.list.d/10-strike-software-nmagent.list
    exit 1
fi
echo "Установка пакета 10-strike-nmagent завершена" &>> $install_log

sudo umount $repo_path
if [[ $? -ne 0 ]]; then echo "Не удалось размонтировать образ с репозиторием..." &>> $install_log; fi

sudo rmdir $repo_path
if [[ $? -ne 0 ]]; then echo "Не удалось удалить каталог ($repo_path)..." &>> $install_log; fi

sudo rm -f /etc/apt/sources.list.d/10-strike-software-nmagent.list
if [[ $? -ne 0 ]]; then echo "Не удалось удалить информацию о репозитории из системы..." &>> $install_log; fi

sudo apt update &>> $install_log

echo "УСТАНОВКА ПРОДУКТА ЗАВЕРШЕНА!" &>> $install_log

exit 0
